# oceanum-python

Python library for working with the [Oceanum.io platform](https://oceanum.io).

Documentation is at: (https://oceanum-python.readthedocs.io/)

## Testing

The default test account has no datamesh write access. To test the write functionality, you will need to replace the DATAMESH_TOKEN in tox.ini with a token from an account with write access.
